django\_sorcery package
=======================

.. automodule:: django_sorcery
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    django_sorcery.db
    django_sorcery.formsets
    django_sorcery.views
    django_sorcery.viewsets

Submodules
----------

.. toctree::

   django_sorcery.compat
   django_sorcery.exceptions
   django_sorcery.field_mapping
   django_sorcery.fields
   django_sorcery.forms
   django_sorcery.routers
   django_sorcery.shortcuts
   django_sorcery.utils
   django_sorcery.validators

